@@ -19,22 +19,22 @@ from ._tfenv import tfenv
 from ._whichenv import whichenv
 
 __all__ = [
-    'deploy',
-    'destroy',
-    'dismantle',
-    'docs',
-    'envvars',
-    'gen_sample',
-    'init',
-    'kbenv',
-    'plan',
-    'preflight',
-    'run_aws',
-    'run_python',
-    'run_stacker',
-    'takeoff',
-    'taxi',
-    'test',
-    'tfenv',
-    'whichenv'
+    "deploy",
+    "destroy",
+    "dismantle",
+    "docs",
+    "envvars",
+    "gen_sample",
+    "init",
+    "kbenv",
+    "plan",
+    "preflight",
+    "run_aws",
+    "run_python",
+    "run_stacker",
+    "takeoff",
+    "taxi",
+    "test",
+    "tfenv",
+    "whichenv",
 ]
