@@ -7,14 +7,20 @@ if sys.version_info >= (3, 6):  # cov: ignore
 else:  # cov: ignore
     AbstractContextManager = object
 
-LOGGER = logging.getLogger(__name__.replace('._', '.'))
+LOGGER = logging.getLogger(__name__.replace("._", "."))
 
 
 class AssumeRole(AbstractContextManager):
     """Context manager for assuming an AWS role."""
 
-    def __init__(self, context, role_arn=None, duration_seconds=None,
-                 revert_on_exit=True, session_name=None):
+    def __init__(
+        self,
+        context,
+        role_arn=None,
+        duration_seconds=None,
+        revert_on_exit=True,
+        session_name=None,
+    ):
         """Instantiate class.
 
         Args:
@@ -34,7 +40,7 @@ class AssumeRole(AbstractContextManager):
         self.ctx = context
         self.duration_seconds = duration_seconds or 3600
         self.revert_on_exit = revert_on_exit
-        self.session_name = session_name or 'runway'
+        self.session_name = session_name or "runway"
 
     @property
     def _kwargs(self):
@@ -45,49 +51,51 @@ class AssumeRole(AbstractContextManager):
 
         """
         return {
-            'RoleArn': self.role_arn,
-            'RoleSessionName': self.session_name,
-            'DurationSeconds': self.duration_seconds
+            "RoleArn": self.role_arn,
+            "RoleSessionName": self.session_name,
+            "DurationSeconds": self.duration_seconds,
         }
 
     def assume(self):
         """Perform role assumption."""
         if not self.role_arn:
-            LOGGER.debug('no role to assume')
+            LOGGER.debug("no role to assume")
             return
         if self.revert_on_exit:
             self.save_existing_iam_env_vars()
-        sts_client = self.ctx.get_session().client('sts')
-        LOGGER.info('assuming role %s...', self.role_arn)
+        sts_client = self.ctx.get_session().client("sts")
+        LOGGER.info("assuming role %s...", self.role_arn)
         response = sts_client.assume_role(**self._kwargs)
-        LOGGER.debug('sts.assume_role respsone: %s', response)
-        self.assumed_role_user.update(response['AssumedRoleUser'])
-        self.credentials.update(response['Credentials'])
-        self.ctx.env.vars.update({
-            'AWS_ACCESS_KEY_ID': response['Credentials']['AccessKeyId'],
-            'AWS_SECRET_ACCESS_KEY': response['Credentials']['SecretAccessKey'],
-            'AWS_SESSION_TOKEN': response['Credentials']['SessionToken']
-        })
-        LOGGER.verbose('updated environment with assumed credentials')
+        LOGGER.debug("sts.assume_role respsone: %s", response)
+        self.assumed_role_user.update(response["AssumedRoleUser"])
+        self.credentials.update(response["Credentials"])
+        self.ctx.env.vars.update(
+            {
+                "AWS_ACCESS_KEY_ID": response["Credentials"]["AccessKeyId"],
+                "AWS_SECRET_ACCESS_KEY": response["Credentials"]["SecretAccessKey"],
+                "AWS_SESSION_TOKEN": response["Credentials"]["SessionToken"],
+            }
+        )
+        LOGGER.verbose("updated environment with assumed credentials")
 
     def restore_existing_iam_env_vars(self):
         """Restore backed up IAM environment variables."""
         if not self.role_arn:
-            LOGGER.debug('no role was assumed; not reverting credentials')
+            LOGGER.debug("no role was assumed; not reverting credentials")
             return
         for k in self.ctx.current_aws_creds.keys():
-            old = 'OLD_' + k
+            old = "OLD_" + k
             if self.ctx.env_vars.get(old):
                 self.ctx.env_vars[k] = self.ctx.env_vars.pop(old)
-                LOGGER.debug('reverted environment variables: %s', k)
+                LOGGER.debug("reverted environment variables: %s", k)
             else:
                 self.ctx.env_vars.pop(k, None)
-                LOGGER.debug('removed environment variables: %s ', k)
+                LOGGER.debug("removed environment variables: %s ", k)
 
     def save_existing_iam_env_vars(self):
         """Backup IAM environment variables for later restoration."""
         for k, v in self.ctx.current_aws_creds.items():
-            new = 'OLD_' + k
+            new = "OLD_" + k
             LOGGER.debug('saving environment variable "%s" as "%s"', k, new)
             self.ctx.env_vars[new] = v
 
@@ -98,7 +106,7 @@ class AssumeRole(AbstractContextManager):
             AssumeRole
 
         """
-        LOGGER.debug('entering aws.AssumeRole context manager...')
+        LOGGER.debug("entering aws.AssumeRole context manager...")
         self.assume()
         return self
 
@@ -106,4 +114,4 @@ class AssumeRole(AbstractContextManager):
         """Exit the context manager."""
         if self.revert_on_exit:
             self.restore_existing_iam_env_vars()
-        LOGGER.debug('aws.AssumeRole context manager exited')
+        LOGGER.debug("aws.AssumeRole context manager exited")
