@@ -1,5 +1,5 @@
 """Tests for runway.cfngin.config."""
-# pylint: disable=no-member
+# pylint: disable=no-member,no-self-use
 import sys
 import unittest
 
@@ -56,112 +56,117 @@ class TestConfig(unittest.TestCase):
 
     def test_config_validate_missing_stack_source(self):
         """Test config validate missing stack source."""
-        config = Config({
-            "namespace": "prod",
-            "stacks": [
-                {
-                    "name": "bastion"}]})
+        config = Config({"namespace": "prod", "stacks": [{"name": "bastion"}]})
         with self.assertRaises(exceptions.InvalidConfig) as ex:
             config.validate()
 
-        stack_errors = ex.exception.errors['stacks'][0]
-        assert stack_errors['template_path'][0].__str__() == \
-            "class_path or template_path is required."
-        assert stack_errors['class_path'][0].__str__() == \
-            "class_path or template_path is required."
+        stack_errors = ex.exception.errors["stacks"][0]
+        assert (
+            stack_errors["template_path"][0].__str__()
+            == "class_path or template_path is required."
+        )
+        assert (
+            stack_errors["class_path"][0].__str__()
+            == "class_path or template_path is required."
+        )
 
     def test_config_validate_missing_stack_source_when_locked(self):
         """Test config validate missing stack source when locked."""
-        config = Config({
-            "namespace": "prod",
-            "stacks": [
-                {
-                    "name": "bastion",
-                    "locked": True}]})
+        config = Config(
+            {"namespace": "prod", "stacks": [{"name": "bastion", "locked": True}]}
+        )
         config.validate()
 
     def test_config_validate_stack_class_and_template_paths(self):
         """Test config validate stack class and template paths."""
-        config = Config({
-            "namespace": "prod",
-            "stacks": [
-                {
-                    "name": "bastion",
-                    "class_path": "foo",
-                    "template_path": "bar"}]})
+        config = Config(
+            {
+                "namespace": "prod",
+                "stacks": [
+                    {"name": "bastion", "class_path": "foo", "template_path": "bar"}
+                ],
+            }
+        )
         with self.assertRaises(exceptions.InvalidConfig) as ex:
             config.validate()
 
-        stack_errors = ex.exception.errors['stacks'][0]
-        assert stack_errors['template_path'][0].__str__() == \
-            "class_path cannot be present when template_path is provided."
-        assert stack_errors['class_path'][0].__str__() == \
-            "template_path cannot be present when class_path is provided."
+        stack_errors = ex.exception.errors["stacks"][0]
+        assert (
+            stack_errors["template_path"][0].__str__()
+            == "class_path cannot be present when template_path is provided."
+        )
+        assert (
+            stack_errors["class_path"][0].__str__()
+            == "template_path cannot be present when class_path is provided."
+        )
 
     def test_config_validate_missing_name(self):
         """Test config validate missing name."""
-        config = Config({
-            "namespace": "prod",
-            "stacks": [
-                {
-                    "class_path": "blueprints.Bastion"}]})
+        config = Config(
+            {"namespace": "prod", "stacks": [{"class_path": "blueprints.Bastion"}]}
+        )
         with self.assertRaises(exceptions.InvalidConfig) as ex:
             config.validate()
 
-        error = ex.exception.errors['stacks'][0]['name'].errors[0]
+        error = ex.exception.errors["stacks"][0]["name"].errors[0]
         assert error.__str__() == "This field is required."
 
     def test_config_validate_duplicate_stack_names(self):
         """Test config validate duplicate stack names."""
-        config = Config({
-            "namespace": "prod",
-            "stacks": [
-                {
-                    "name": "bastion",
-                    "class_path": "blueprints.Bastion"},
-                {
-                    "name": "bastion",
-                    "class_path": "blueprints.BastionV2"}]})
+        config = Config(
+            {
+                "namespace": "prod",
+                "stacks": [
+                    {"name": "bastion", "class_path": "blueprints.Bastion"},
+                    {"name": "bastion", "class_path": "blueprints.BastionV2"},
+                ],
+            }
+        )
         with self.assertRaises(exceptions.InvalidConfig) as ex:
             config.validate()
 
-        error = ex.exception.errors['stacks'][0]
+        error = ex.exception.errors["stacks"][0]
         assert error.__str__() == "Duplicate stack bastion found at index 0."
 
     def test_dump_unicode(self):
         """Test dump unicode."""
         config = Config()
         config.namespace = "test"
-        assert dump(config) == b"""namespace: test
+        assert (
+            dump(config)
+            == b"""namespace: test
 stacks: []
 """
+        )
 
         config = Config({"namespace": "test"})
         # Ensure that we're producing standard yaml, that doesn't include
         # python specific objects.
         assert dump(config) != b"namespace: !!python/unicode 'test'\n"
-        assert dump(config) == b"""namespace: test
+        assert (
+            dump(config)
+            == b"""namespace: test
 stacks: []
 """
+        )
 
     def test_parse_tags(self):
         """Test parse tags."""
-        config = parse("""
+        config = parse(
+            """
         namespace: prod
         tags:
           "a:b": "c"
           "hello": 1
           simple_tag: simple value
-        """)
-        assert config.tags == {
-            "a:b": "c",
-            "hello": "1",
-            "simple_tag": "simple value"
-        }
+        """
+        )
+        assert config.tags == {"a:b": "c", "hello": "1", "simple_tag": "simple value"}
 
     def test_parse_with_arbitrary_anchors(self):
         """Test parse with arbitrary anchors."""
-        config = parse("""
+        config = parse(
+            """
         namespace: prod
         common_variables: &common_variables
           Foo: bar
@@ -170,25 +175,28 @@ stacks: []
           class_path: blueprints.VPC
           variables:
             << : *common_variables
-        """)
+        """
+        )
 
         stack = config.stacks[0]
         assert stack.variables == {"Foo": "bar"}
 
     def test_parse_with_deprecated_parameters(self):
         """Test parse with deprecated parameters."""
-        config = parse("""
+        config = parse(
+            """
         namespace: prod
         stacks:
         - name: vpc
           class_path: blueprints.VPC
           parameters:
             Foo: bar
-        """)
+        """
+        )
         with self.assertRaises(exceptions.InvalidConfig) as ex:
             config.validate()
 
-        error = ex.exception.errors['stacks'][0]['parameters'][0]
+        error = ex.exception.errors["stacks"][0]["parameters"][0]
         assert error.__str__() == (
             "DEPRECATION: Stack definition vpc contains deprecated 'parameters'"
             ", rather than 'variables'. You are required to update your config. "
@@ -200,9 +208,9 @@ stacks: []
         """Test config build."""
         vpc = Stack({"name": "vpc", "class_path": "blueprints.VPC"})
         config = Config({"namespace": "prod", "stacks": [vpc]})
-        assert config.namespace == 'prod'
-        assert config.stacks[0].name == 'vpc'
-        assert config["namespace"] == 'prod'
+        assert config.namespace == "prod"
+        assert config.stacks[0].name == "vpc"
+        assert config["namespace"] == "prod"
         config.validate()
 
     def test_parse(self):
@@ -355,31 +363,42 @@ stacks: []
 
             config.validate()
 
-            assert config.namespace == 'prod'
-            assert config.stacker_bucket == 'cfngin-prod'
+            assert config.namespace == "prod"
+            assert config.stacker_bucket == "cfngin-prod"
 
-            for hooks in [config.pre_build, config.post_build,
-                          config.pre_destroy, config.post_destroy]:
-                assert hooks[0].path == 'runway.cfngin.hooks.route53.create_domain'
+            for hooks in [
+                config.pre_build,
+                config.post_build,
+                config.pre_destroy,
+                config.post_destroy,
+            ]:
+                assert hooks[0].path == "runway.cfngin.hooks.route53.create_domain"
                 assert hooks[0].required
                 assert hooks[0].args == {"domain": "mydomain.com"}
 
-            assert config.package_sources.s3[0].bucket == 'acmecorpbucket'
-            assert config.package_sources.s3[0].key == \
-                'public/acmecorp-blueprints-v1.zip'
-            assert config.package_sources.s3[1].bucket == 'examplecorpbucket'
-            assert config.package_sources.s3[1].key == \
-                'public/examplecorp-blueprints-v2.tar.gz'
+            assert config.package_sources.s3[0].bucket == "acmecorpbucket"
+            assert (
+                config.package_sources.s3[0].key == "public/acmecorp-blueprints-v1.zip"
+            )
+            assert config.package_sources.s3[1].bucket == "examplecorpbucket"
+            assert (
+                config.package_sources.s3[1].key
+                == "public/examplecorp-blueprints-v2.tar.gz"
+            )
             assert config.package_sources.s3[1].requester_pays
             assert not config.package_sources.s3[2].use_latest
 
-            assert config.package_sources.git[0].uri == \
-                'git@github.com:acmecorp/stacker_blueprints.git'
-            assert config.package_sources.git[1].uri == \
-                'git@github.com:remind101/stacker_blueprints.git'
-            assert config.package_sources.git[1].tag == '1.0.0'
-            assert config.package_sources.git[1].paths == ['stacker_blueprints']
-            assert config.package_sources.git[2].branch == 'staging'
+            assert (
+                config.package_sources.git[0].uri
+                == "git@github.com:acmecorp/stacker_blueprints.git"
+            )
+            assert (
+                config.package_sources.git[1].uri
+                == "git@github.com:remind101/stacker_blueprints.git"
+            )
+            assert config.package_sources.git[1].tag == "1.0.0"
+            assert config.package_sources.git[1].paths == ["stacker_blueprints"]
+            assert config.package_sources.git[2].branch == "staging"
 
             assert config.tags == {"environment": "production"}
 
@@ -387,14 +406,13 @@ stacks: []
             self.assertEqual(len(config.stacks), 2)
 
             vpc_index = next(
-                i for (i, d) in enumerate(config.stacks) if d.name == 'vpc'
+                i for (i, d) in enumerate(config.stacks) if d.name == "vpc"
             )
             vpc = config.stacks[vpc_index]
             self.assertEqual(vpc.name, "vpc")
             self.assertEqual(vpc.class_path, "blueprints.VPC")
             self.assertEqual(vpc.requires, None)
-            self.assertEqual(vpc.variables,
-                             {"PrivateSubnets": ["10.0.0.0/24"]})
+            self.assertEqual(vpc.variables, {"PrivateSubnets": ["10.0.0.0/24"]})
 
             bastion_index = next(
                 i for (i, d) in enumerate(config.stacks) if d.name == "bastion"
@@ -403,23 +421,29 @@ stacks: []
             self.assertEqual(bastion.name, "bastion")
             self.assertEqual(bastion.class_path, "blueprints.Bastion")
             self.assertEqual(bastion.requires, ["vpc"])
-            self.assertEqual(bastion.variables,
-                             {"VpcId": "${output vpc::VpcId}"})
+            self.assertEqual(bastion.variables, {"VpcId": "${output vpc::VpcId}"})
 
     def test_dump_complex(self):
         """Test dump complex."""
-        config = Config({
-            "namespace": "prod",
-            "stacks": [
-                Stack({
-                    "name": "vpc",
-                    "class_path": "blueprints.VPC"}),
-                Stack({
-                    "name": "bastion",
-                    "class_path": "blueprints.Bastion",
-                    "requires": ["vpc"]})]})
+        config = Config(
+            {
+                "namespace": "prod",
+                "stacks": [
+                    Stack({"name": "vpc", "class_path": "blueprints.VPC"}),
+                    Stack(
+                        {
+                            "name": "bastion",
+                            "class_path": "blueprints.Bastion",
+                            "requires": ["vpc"],
+                        }
+                    ),
+                ],
+            }
+        )
 
-        self.assertEqual(dump(config), b"""namespace: prod
+        self.assertEqual(
+            dump(config),
+            b"""namespace: prod
 stacks:
 - class_path: blueprints.VPC
   enabled: true
@@ -435,13 +459,12 @@ stacks:
   requires:
   - vpc
   termination_protection: false
-""")
+""",
+        )
 
     def test_load_register_custom_lookups(self):
         """Test load register custom lookups."""
-        config = Config({
-            "lookups": {
-                "custom": "importlib.import_module"}})
+        config = Config({"lookups": {"custom": "importlib.import_module"}})
         load(config)
         self.assertTrue(callable(CFNGIN_LOOKUP_HANDLERS["custom"]))
 
@@ -463,10 +486,12 @@ stacks:
 
     def test_lookup_with_sys_path(self):
         """Test lookup with sys path."""
-        config = Config({
-            "sys_path": "./tests/unit/cfngin",
-            "lookups": {
-                "custom": "fixtures.mock_lookups.handler"}})
+        config = Config(
+            {
+                "sys_path": "./tests/unit/cfngin",
+                "lookups": {"custom": "fixtures.mock_lookups.handler"},
+            }
+        )
         load(config)
         self.assertTrue(callable(CFNGIN_LOOKUP_HANDLERS["custom"]))
 
@@ -478,9 +503,10 @@ stacks:
           class_path: blueprints.VPC
         """
         config = render_parse_load(
-            conf, environment={"namespace": "prod"}, validate=False)
+            conf, environment={"namespace": "prod"}, validate=False
+        )
         config.validate()
-        assert config.namespace == 'prod'
+        assert config.namespace == "prod"
 
     def test_allow_most_keys_to_be_duplicates_for_overrides(self):
         """Test allow most keys to be duplicates for overrides."""
@@ -495,9 +521,7 @@ stacks:
         """
         doc = parse(yaml_config)
         print(doc.to_primitive())
-        self.assertEqual(
-            doc["stacks"][0]["variables"]["CIDR"], "192.168.2.0/24"
-        )
+        self.assertEqual(doc["stacks"][0]["variables"]["CIDR"], "192.168.2.0/24")
         yaml_config = """
         default_variables: &default_variables
           CIDR: 192.168.1.0/24
@@ -510,9 +534,7 @@ stacks:
               CIDR: 192.168.2.0/24
         """
         doc = parse(yaml_config)
-        self.assertEqual(
-            doc["stacks"][0]["variables"]["CIDR"], "192.168.2.0/24"
-        )
+        self.assertEqual(doc["stacks"][0]["variables"]["CIDR"], "192.168.2.0/24")
 
     def test_raise_constructor_error_on_keyword_duplicate_key(self):
         """Some keys should never have a duplicate sibling.
@@ -576,10 +598,10 @@ stacks:
         config = parse(yaml_config)
         # config.validate()
 
-        assert config.cfngin_bucket == ''
-        assert config.cfngin_bucket_region == 'us-east-1'
-        assert config.cfngin_cache_dir == './test/path'
+        assert config.cfngin_bucket == ""
+        assert config.cfngin_bucket_region == "us-east-1"
+        assert config.cfngin_cache_dir == "./test/path"
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     unittest.main()
